##########################################################################
#                                                                        #
#        RichTopic 1.1                                     #
#        copyright (c) 2005 Wolf and Associates                          #
#        written by: David Siedband david@wolfandassociates.com          #
#        open-source under the GPL v2.1 (see LICENSE.txt)                #
#                                                                        #
##########################################################################

"""plone installer script"""

from Products.CMFCore.utils import getToolByName
from Products.CMFFormController.FormAction import FormActionKey
from Products.Archetypes.public import listTypes
from Products.Archetypes.Extensions.utils import installTypes, install_subskin
from Products.RichTopic.config import *

from StringIO import StringIO

def install(self):
    """install the atct"""
    out = StringIO()

    installTypes(self, out,
                 listTypes(PROJECTNAME),
                 PROJECTNAME)

    install_subskin(self, out, GLOBALS)

    propsTool = getToolByName(self, 'portal_properties')
    siteProperties = getattr(propsTool, 'site_properties')

    # Add to default_page_types
    defaultPageTypes = list(siteProperties.getProperty('default_page_types'))
    for type in ("RichTopic",):
        if type not in defaultPageTypes:
            defaultPageTypes.append(type)
    siteProperties.manage_changeProperties(default_page_types = defaultPageTypes)

    # Add RichTopic to Kupu's linkable types
    kupuTool = getToolByName(self, 'kupu_library_tool')
    linkable = list(kupuTool.getPortalTypesForResourceType('linkable'))
    collection = list(kupuTool.getPortalTypesForResourceType('collection'))
    mediaobject = list(kupuTool.getPortalTypesForResourceType('mediaobject'))

    for t in ("RichTopic",):
        if t not in linkable:
            linkable.append(t)

    # kupu_library_tool has an odd interface, basically written purely to
    # work with its configuration page. :-(
    kupuTool.updateResourceTypes(({'resource_type' : 'linkable',
                                   'old_type'      : 'linkable',
                                   'portal_types'  :  linkable},
                                  {'resource_type' : 'mediaobject',
                                   'old_type'      : 'mediaobject',
                                   'portal_types'  :  mediaobject},
                                  {'resource_type' : 'collection',
                                   'old_type'      : 'collection',
                                   'portal_types'  :  collection},))
    print >> out, "Added RichTopic to kupu's linkable types"

    print >> out, "Successfully installed %s." % PROJECTNAME
    return out.getvalue()
    
def uninstall(portal, reinstall=False):
    """Remove RichTopic cruft"""
    out = StringIO()

    print >> out, "Uninstalling RichTopic"
    
    # 1: Fix Kupu settings
    #    Remove RichTopic types from kupu's linkable types
    kupuTool = getToolByName(portal, 'kupu_library_tool')
    linkable    = list(kupuTool.getPortalTypesForResourceType('linkable'))
    collection  = list(kupuTool.getPortalTypesForResourceType('collection'))
    mediaobject = list(kupuTool.getPortalTypesForResourceType('mediaobject'))

    for t in ("RichTopic",):
        if t in linkable:
            linkable.remove(t)

    kupuTool.updateResourceTypes(({'resource_type' : 'linkable',
                                   'old_type'      : 'linkable',
                                   'portal_types'  :  linkable},
                                  {'resource_type' : 'mediaobject',
                                   'old_type'      : 'mediaobject',
                                   'portal_types'  :  mediaobject},
                                  {'resource_type' : 'collection',
                                   'old_type'      : 'collection',
                                   'portal_types'  :  collection},))
    print >> out, "Removed reference to RichTopic from kupu's linkable types"

    # 2: Remove RichTopic's contributions to various portal_properties.site_properties props
    props_tool = getToolByName(portal, 'portal_properties')
    if hasattr(props_tool, 'site_properties'):
        site_properties = getattr(props_tool, 'site_properties')

        # default_page_types
        defaultPageTypes = list(site_properties.getProperty('default_page_types'))
        for t in ("RichTopic",):
            if t in defaultPageTypes:
                defaultPageTypes.remove(t)
        site_properties.manage_changeProperties(default_page_types = defaultPageTypes)
        print >> out, "Removed RichTopic from default page types" 

    return out.getvalue()    
